import { Component, EventEmitter, Input, OnInit, Output, SimpleChanges, ViewChild } from '@angular/core';
import { ActivatedRoute, Params } from '@angular/router';
import { Observable, Subject, from, mergeMap, of, switchMap, takeUntil, tap } from 'rxjs';
import { ComponentHostDirective } from '../directives/component-host.directive';
import { ServiceComponentType, servicesComponentFactory } from '../services-factory';
import { HttpClient, HttpClientModule, HttpHeaders } from '@angular/common/http';
import { Service, ServiceTypes, WidjetService } from './widjet.service';
import { jwtDecode } from "jwt-decode";
@Component({
  selector: 'app-services',
  standalone: true,
  imports: [ComponentHostDirective, HttpClientModule],
  templateUrl: './services.component.html',
  styleUrls: ['./services.component.scss'],
})
export class ServicesComponent implements OnInit {
  @Input() token?: string;
  @Input() companyId?: string;
  @Input() id?: number;
  @Output() valueChange: EventEmitter<Service> = new EventEmitter<Service>();
  widjetSelect?: Service


  @ViewChild(ComponentHostDirective, { static: true }) componentHost!: ComponentHostDirective;

  constructor(private readonly route: ActivatedRoute, private widjetService: WidjetService, private http: HttpClient) { }

  destroy: Subject<void> = new Subject<void>();

  ngOnInit(): void { // subscribing to the stream when component has been created
    // this.getOne(this.id!).subscribe(result => {
    //   this.loadComponent(result)
    // })
    this.route.params
      .pipe(
        mergeMap(({ id }: Params) => this.getOne(id! ? id : this.id)),
        tap((service: Service) => this.loadComponent(service)),
        takeUntil(this.destroy.asObservable()),
      )
      .subscribe(result => {
      });






  }

  ngOnChanges(changes: SimpleChanges): void {
    console.log(changes)
    if (changes) {
      this.destroy.asObservable()
      this.id = changes['id'].currentValue
      this.getOne(this.id!).subscribe(result => {
        this.widjetSelect = result
        if (this.token) {
          console.log(this.token)
          this.loadData(this.widjetSelect)
        } else {
          this.loadComponent(this.widjetSelect)
        }

      })
    }

    //Called before any other lifecycle hook. Use it to inject dependencies, but avoid any serious work here.
    //Add '${implements OnChanges}' to the class.

  }

  loadComponent(service: Service): void {
    const { viewContainerRef }: ComponentHostDirective = this.componentHost;
    viewContainerRef.clear();

    const { instance } = viewContainerRef.createComponent<ServiceComponentType>(
      servicesComponentFactory[service.id as ServiceTypes]
    );
    if (service.dataSoure) {
      instance.model = service.dataSoure;
    }else{
      service.dataModel = instance.model;
    }


  }

  // setComponent(service: Service): void {
  //   const { viewContainerRef }: ComponentHostDirective = this.componentHost;
  //   viewContainerRef.clear();

  //   const { instance } = viewContainerRef.createComponent<ServiceComponentType>(
  //     servicesComponentFactory[service.id as ServiceTypes]
  //   );
  //   instance.model = service.dataSoure
  // }

  ngOnDestroy(): void {
    this.destroy.next();
  }

  getOne(num: number): Observable<Service> {
    console.log("num", num)
    let componentFilter = this.widjetService.widjetList.filter(e =>
      e.id == num)[0];
    return of(componentFilter)
  }

  loadData(widget: Service) {
    const user: any = jwtDecode(this.token!)
    widget.api = widget.api.replace('${companyId}', this.companyId!).replace('${memberId}', user.uid)
    const options = {
      headers: new HttpHeaders({
        "Authorization": "Bearer " + this.token,
      }),
    };
    this.http.get(widget.api, options).subscribe(result => {
      console.log("token", result)
      widget.dataSoure = result
      this.loadComponent(widget)
    })
  }
}
